@@ -1,11 +1,12 @@
-#  tests for pycryptodomex-3.7.3-py36hfa6e2cd_0 (this is a generated file);
-print('===== testing package: pycryptodomex-3.7.3-py36hfa6e2cd_0 =====');
+#  tests for pycryptodomex-3.8.0-py36hfa6e2cd_0 (this is a generated file);
+print('===== testing package: pycryptodomex-3.8.0-py36hfa6e2cd_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import os
 import re
 import psutil
 import platform
+import subprocess
 
 libname = re.escape(os.environ['CONDA_PREFIX']) + '.*(libgmp.*.(dylib|so))'
 
@@ -18,11 +19,16 @@ if not psutil.WINDOWS:
     from Cryptodome.Math import _IntegerGMP as IntegerGMP
 
     # Make sure that gmp is indeed loaded in memory
-    p = psutil.Process(os.getpid())
-    assert any(bool(re.match(libname, x.path)) for x in p.memory_maps())
+    if psutil.MACOS:
+        vmmap_out = subprocess.check_output(['vmmap', '-w', str(os.getpid())])
+        assert re.search(re.compile(libname), vmmap_out.decode('utf-8'))
+
+    if psutil.LINUX:
+        p = psutil.Process(os.getpid())
+        assert any(bool(re.match(libname, x.path)) for x in p.memory_maps())
 #  --- run_test.py (end) ---
 
-print('===== pycryptodomex-3.7.3-py36hfa6e2cd_0 OK =====');
+print('===== pycryptodomex-3.8.0-py36hfa6e2cd_0 OK =====');
 print("import: 'Cryptodome'")
 import Cryptodome
 
